@@ -1,13 +1,15 @@
+//#include <QTimer>
 #include "alarmwindow.h"
 #include "ui_alarmwindow.h"
 
 #if  defined(Q_WS_MAEMO_5)
 #include <QtDBus/QtDBus>
 #include <time.h>
-#include <alarm_dbus.h>
-#include <libalarm.h>
+#include <alarmd/alarm_dbus.h>
+#include <alarmd/libalarm.h>
 #endif
 
+
 //#include <QLocale>
 #include "settingsdialog.h"
 #include "nalarmsettings.h"
@@ -16,9 +18,10 @@
 #define clockIconPath "/usr/share/icons/hicolor/48x48/hildon/general_clock.png"
 #define recurIconPath "/usr/share/icons/hicolor/48x48/hildon/general_refresh.png"
 
-static int fntAdd = 3;
+static int FNT_ADD = 3;
 //static int iconWidth = 30;
-static int nextPeriod = 86400; // look forward for 24 hours
+static int NEXT_PERIOD = 86400; // look forward for 24 hours
+static QString STD_ALARM_ID("worldclock_alarmd_id");
 
 AlarmWindow::AlarmWindow(QWidget *parent) :
     QWidget(parent),
@@ -31,6 +34,9 @@ AlarmWindow::AlarmWindow(QWidget *parent) :
     loadSettings();
     fillAlarmList();
     updateUi();
+
+    m_timer = new QTimer(this);
+    connect(m_timer, SIGNAL(timeout()), this, SLOT(fillAlarmList()));
 }
 
 AlarmWindow::~AlarmWindow()
@@ -49,7 +55,7 @@ void AlarmWindow::fillAlarmList()
 
     ui->listWidget->clear();
     QFontMetrics fm(m_font);
-    int fntHeight = fm.height() + fntAdd;
+    int fntHeight = fm.height() + FNT_ADD;
 
     if (m_showCaption)
     {
@@ -72,7 +78,7 @@ void AlarmWindow::fillAlarmList()
     time_t now;
 
     now = time(NULL);
-    list = alarmd_event_query(now, now + nextPeriod, ALARM_EVENT_DISABLED, 0, NULL);
+    list = alarmd_event_query(now, now + NEXT_PERIOD, ALARM_EVENT_DISABLED, 0, NULL);
     if (list == NULL) {
             fprintf(stderr, "alarm_event_query() failed\n");
     }
@@ -86,7 +92,19 @@ void AlarmWindow::fillAlarmList()
                 item->setForeground(m_color);
                 item->setFont(m_font);
 
-                    alarm_event_t * aevent = alarmd_event_get (*iter);
+                alarm_event_t * aevent = alarmd_event_get (*iter);
+
+/*                    if (QString::fromUtf8(aevent->alarm_appid) == QString("Enter_name"))
+                {
+                    qDebug() << "error alarm found";
+                    alarmd_event_del(*iter);
+                }
+*/
+                if ((!m_showStdOnly) || ((m_showStdOnly) && (QString::fromUtf8(aevent->alarm_appid) == STD_ALARM_ID)))
+                {
+//                        qDebug() << "real alarm found";
+  //                  }
+
                     int recur = alarm_event_is_recurring (aevent);
                     bool toAdd = false;
                     time_t ttime;
@@ -121,11 +139,24 @@ void AlarmWindow::fillAlarmList()
                         QDateTime qdtm = QDateTime::fromTime_t(ttime);
                         QTime qtm = qdtm.time();
                         QString sTime = qtm.toString(Qt::DefaultLocaleShortDate);
-                        if (!aTitle.isEmpty())
-                            sTime = sTime + " (" + aTitle + ")";
+                        if (m_showRemain) // calc remaining time
+                        {
+                            QTime currTime = QTime::currentTime();
+                            int remain = currTime.secsTo(qtm);
+                            if (remain < 0) remain += 86400;
+                            int h = remain/3600;
+                            int m = (remain - h*3600)/60;
+                            QTime remTime(h,m);
+                            QString sRemTime = " > " + remTime.toString("H:mm");
+                            sTime += sRemTime;
+                        }
+
+                        if ((!aTitle.isEmpty()) && m_showTitle ) // show title of alarm
+                            sTime += " : \"" + aTitle + "\"";
                         item->setText(sTime);
                         ui->listWidget->addItem(item);
                     }
+                }
             }
     }
     free(list);
@@ -135,7 +166,8 @@ void AlarmWindow::fillAlarmList()
         item->setSizeHint(QSize (m_width-fntHeight,fntHeight));
         item->setForeground(m_color);
         item->setFont(m_font);
-        item->setText(tr("no active alarms"));
+//        item->setText(tr("no active alarms"));
+        item->setText(tr("--:--"));
         ui->listWidget->addItem(item);
     }
 #else
@@ -179,6 +211,8 @@ void AlarmWindow::showSettingsDialog()
 
         dialog.dumpSettings();
         loadSettings();
+        fillAlarmList();
+        updateUi();
     }
 }
 
@@ -188,16 +222,23 @@ void AlarmWindow::loadSettings()
     m_numberAlarms = nalarmsettings::getInstance().getSize();
     m_width = nalarmsettings::getInstance().getWidth();
     m_font = nalarmsettings::getInstance().getFont();
-    m_showCaption = nalarmsettings::getInstance().showHeader();
+    m_showCaption = nalarmsettings::getInstance().isShowHeader();
+    m_showRemain = nalarmsettings::getInstance().isShowRemain();
+    m_showTitle = nalarmsettings::getInstance().isShowTitle();
+    m_showStdOnly = nalarmsettings::getInstance().isStdOnly();
 }
 
 void AlarmWindow::homeScreenChanged(bool isOnCurrentHomescreen)
 {
+    if (m_timer->isActive())
+        m_timer->stop();
     if (isOnCurrentHomescreen)
     {
         fillAlarmList();
-        updateUi();    }
-    //TODO update display
+//        updateUi();
+        if (m_showRemain)
+            m_timer->start(1000);
+    }
 }
 
 void AlarmWindow::updateUi()
@@ -206,13 +247,14 @@ void AlarmWindow::updateUi()
     int y = geometry().y();
     int listHeight;
     QFontMetrics fm(m_font);
-    int fntHeight = fm.height() + fntAdd;
+    int fntHeight = fm.height() + FNT_ADD;
     if (m_showCaption)
     {
         listHeight = ((m_numberAlarms + 1) * (fntHeight) + 20);
     }
     else
         listHeight = ((m_numberAlarms) * (fntHeight)+20);
+    if (listHeight > 430 ) listHeight = 430;
     ui->listWidget->setIconSize(QSize(fntHeight/2,fntHeight/2));
     setGeometry(x,y,m_width,listHeight);
 }
