@@ -55,6 +55,9 @@ void SettingsDialog::dumpSettings() const
     fnt.setPointSize(ui->spinFontSize->value());
     nalarmsettings::getInstance().setFont(fnt);
     nalarmsettings::getInstance().setShowHeader(ui->cbShowHeader->isChecked());
+    nalarmsettings::getInstance().setShowRemain(ui->chbRemain->isChecked());
+    nalarmsettings::getInstance().setShowTitle(ui->chbTitle->isChecked());
+    nalarmsettings::getInstance().setStdOnly(ui->chbStdOnly->isChecked());
 }
 
 void SettingsDialog::loadSettings()
@@ -64,14 +67,17 @@ void SettingsDialog::loadSettings()
     qp.setColor(QPalette::WindowText,dColor);
     ui->labelColor->setPalette(qp);
     int wSize = nalarmsettings::getInstance().getSize();
-    ui->cbShowHeader->setChecked(nalarmsettings::getInstance().showHeader());
+    ui->cbShowHeader->setChecked(nalarmsettings::getInstance().isShowHeader());
+    ui->chbRemain->setChecked(nalarmsettings::getInstance().isShowRemain());
+    ui->chbTitle->setChecked(nalarmsettings::getInstance().isShowTitle());
+    ui->chbStdOnly->setChecked(nalarmsettings::getInstance().isStdOnly());
     ui->spinSize->setValue(wSize);
     ui->spinWidth->setValue(nalarmsettings::getInstance().getWidth());
     {
         bool found = false;
         QFont fnt(nalarmsettings::getInstance().getFont());
         QString fnt_family(fnt.family());
-        for (int i = 1; i < ui->cbFont->count(); i++)
+        for (int i = 0; i < ui->cbFont->count(); i++)
         {
         if (ui->cbFont->itemText(i) == fnt_family)
             {
@@ -94,7 +100,7 @@ void SettingsDialog::loadSettings()
 void SettingsDialog::showAbout()
 {
     QMessageBox::about(this, tr("About Next Alarm"),
-                        tr("<b>Next Alarm</b> 0.1.0<br>"
+                        tr("<b>Next Alarm</b> 0.1.6<br>"
                         "Using <b>Qt 4.6.2</b><br>"
                         "Copyright (c) 2010 Avis<br>"
                         "<a href=\"mailto:avis@allnokia.ru\">avis@allnokia.ru</a><br><br>"
